window.noi = {
  html2canvas: window.html2canvas,
  TurndownGfm: window.turndownPluginGfm,
  Turndown: window.TurndownService,
  parseMD(html) {
    const hljsREG = /^.*(hljs).*(language-[a-z0-9]+).*$/i;
    const gfm = window.turndownPluginGfm.gfm;
    const turndownService = new window.TurndownService({
      headingStyle: 'atx',
      bulletListMarker: '-',
      strongDelimiter: '**',
      emDelimiter: '_',
      codeBlockStyle: 'fenced',
      fence: '```',
      linkStyle: 'inlined',
      hr: '---',
    })
      .addRule('code', {
        filter(node) {
          if (node.nodeName === 'CODE' && hljsREG.test(node.classList.value)) {
            return true;
          }
          return false;
        },
        replacement(content, node) {
          const classStr = node.getAttribute('class');
          if (hljsREG.test(classStr)) {
            const lang = classStr.match(/.*language-(\w+)/)[1];
            if (lang) {
              return `\`\`\`${lang}\n${content}\n\`\`\``;
            }
            return `\`\`\`\n${content}\n\`\`\``;
          }
          return content;
        },
      })
      .addRule('ignore-text', {
        filter: (node) => {
          if (node.nodeName === 'DIV' && node.classList.contains('!invisible')) {
            return true;
          }
          return false;
        },
        replacement: () => '',
      })
      .addRule('ignore', {
        filter: ['button', 'img', 'input', 'textarea', 'svg'],
        replacement: () => '',
      })
      .addRule('ignoreCertainClasses', {
        filter(node) {
          return ['#noi-watermark'].some((selector) => node.matches(selector));
        },
        replacement: () => '',
      })
      .addRule('table', {
        filter: 'table',
        replacement(content) {
          return `\`\`\`${content}\n\`\`\``;
        },
      });
    turndownService.use(gfm);
    return turndownService.turndown(html);
  },
}
